==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesBar.php <==
<?php
/** Bavarian (Boarisch)
 *
 * @addtogroup Language
 *
 * @author SPQRobin
 * @author Siebrand
 */

$fallback = 'de';

$messages = array(
'about'    => 'Üba',
'mypage'   => 'Eigne Seitn',
'mytalk'   => 'Eigne Diskussion',
'anontalk' => 'Diskussionsseitn vo dera IP',

'edit'              => 'werkln',
'delete'            => 'löschn',
'unprotect'         => 'freigem',
'unprotectthispage' => 'Schutz aufhem',
'talk'              => 'bschprecha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite' => 'Üba {{SITENAME}}',
'aboutpage' => 'Project:Üba_{{SITENAME}}',
'mainpage'  => 'Hauptsaitn',

'youhavenewmessagesmulti' => 'Sie ham neie Nachrichten: $1',

# General errors
'filedeleteerror' => 'De Datei „$1“ håt net glöscht wern kinna.',

# Login and logout pages
'yourname'                   => 'Benutzernam:',
'yourdomainname'             => 'Eanane Domain:',
'notloggedin'                => 'Net ogmeldt',
'yourrealname'               => 'Echter Nam:',
'yourlanguage'               => 'Sprache vo da Benutzeroberfläche:',
'wrongpassword'              => "Des Passwort is falsch (oda fehlt). Bitte probier's no amoi.",
'wrongpasswordempty'         => 'Des eigemne Passwort is laar gwen. Bitte no amoi probiern.',
'acct_creation_throttle_hit' => 'Du hosst scho $1 Benutzakonten und kinnan iatzat koane mehr oleng.',
'accountcreated'             => 'Benutzerkonto is erstellt worn',
'accountcreatedtext'         => "'s Benutzerkonto $1 is eigricht worn.",

# Edit pages
'watchthis'          => 'De Seitn beobachtn',
'whitelistedittitle' => 'Zum Bearbatn miaßn Sie si oomeidn',
'whitelistedittext'  => 'Sie miaßn si $1, um Seiten bearbatn zum kinna.',
'whitelistreadtitle' => 'Zum Lesn is erforderlich, ogmeldt zum sei',
'whitelistreadtext'  => 'Sie miaßn si [[Special:Userlogin|da oomeidn]], um de Seitn lesen zum kinna.',
'whitelistacctitle'  => 'Sie san net berechtigt, a Benutzerkonto ozumlegn.',
'accmailtitle'       => 'Passwort is vaschickt worn',
'newarticle'         => '(Nei)',
'yourtext'           => 'Eana Text',

# History pages
'histlast' => 'Neiste',

# Preferences page
'mypreferences' => 'Eistellunga',

# Upload
'watchthisupload' => 'De Seitn beobachtn',

# Miscellaneous special pages
'allpages'     => 'Alle Seitn',
'newpages'     => 'Neie Seitn',
'ancientpages' => 'Scho länger nimma bearbate Artikel',
'move'         => 'vaschiam',

# Special:Log
'all-logs-page' => 'Alle Logbiacha',

# Special:Allpages
'allarticles'       => 'Alle Seitn',
'allinnamespace'    => 'Alle Seitn (Namensraum: $1)',
'allnotinnamespace' => 'Alle Seitn (net im $1 Namensraum)',
'allpagesprev'      => 'Vorige',
'allpagessubmit'    => 'Owendn',
'allpagesprefix'    => 'Seitn zoagn mit Präfix:',

# Watchlist
'mywatchlist'       => 'Beobachtungslistn',
'watchlistanontext' => 'Sie miaßn si $1, um Eanane Beobachtungslistn zum seng oda Einträge auf ihr zum bearbatn.',
'watchnologin'      => 'Sie san net ogmeidt',
'watchthispage'     => 'Seitn beobachtn',
'unwatch'           => 'nimma beobachten',

# Contributions
'mycontris' => 'Eigene Beiträg',

# What links here
'whatlinkshere' => 'Links auf de Seitn',

# Move page
'movepage'        => 'Seitn vaschiam',
'move-watch'      => 'De Seitn beobachten',
'1movedto2'       => 'håt [[$1]] nåch [[$2]] verschom',
'1movedto2_redir' => 'håt [[$1]] nåch [[$2]] verschom und dabei a Weiterleitung überschriem',

# Namespace 8 related
'allmessagesname'     => 'Nam',
'allmessagescurrent'  => 'Aktuella Text',
'allmessagestext'     => 'Des is a Listn vo de MediaWiki-Systemtexte.',
'allmessagesmodified' => 'Nur geänderte zoagn',

# Special:Newimages
'newimages' => 'Neie Dateien',

);

==> mediawiki-1.13.3.tar.gz: mediawiki-1.13.3/languages/messages/MessagesBar.php <==
<?php
/** Bavarian (Boarisch)
 *
 * @ingroup Language
 * @file
 *
 * @author Malafaya
 */

$fallback = 'de';

$messages = array(
'about'    => 'Üba',
'mypage'   => 'Eigne Seitn',
'mytalk'   => 'Eigne Diskussion',
'anontalk' => 'Diskussionsseitn vo dera IP',

'edit'              => 'werkln',
'delete'            => 'löschn',
'unprotect'         => 'freigem',
'unprotectthispage' => 'Schutz aufhem',
'talk'              => 'bschprecha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Üba {{SITENAME}}',
'aboutpage'            => 'Project:Üba_{{SITENAME}}',
'mainpage'             => 'Hauptsaitn',
'mainpage-description' => 'Hauptsaitn',

'youhavenewmessagesmulti' => 'Sie ham neie Nachrichten: $1',

# General errors
'filedeleteerror' => 'De Datei „$1“ håt net glöscht wern kinna.',

# Login and logout pages
'yourname'                   => 'Benutzernam:',
'yourdomainname'             => 'Eanane Domain:',
'notloggedin'                => 'Net ogmeldt',
'yourrealname'               => 'Echter Nam:',
'yourlanguage'               => 'Sprache vo da Benutzeroberfläche:',
'wrongpassword'              => "Des Passwort is falsch (oda fehlt). Bitte probier's no amoi.",
'wrongpasswordempty'         => 'Des eigemne Passwort is laar gwen. Bitte no amoi probiern.',
'acct_creation_throttle_hit' => 'Du hosst scho $1 Benutzakonten und kinnan iatzat koane mehr oleng.',
'accountcreated'             => 'Benutzerkonto is erstellt worn',
'accountcreatedtext'         => "'s Benutzerkonto $1 is eigricht worn.",

# Edit pages
'watchthis'          => 'De Seitn beobachtn',
'whitelistedittitle' => 'Zum Bearbatn miaßn Sie si oomeidn',
'whitelistedittext'  => 'Sie miaßn si $1, um Seiten bearbatn zum kinna.',
'accmailtitle'       => 'Passwort is vaschickt worn',
'newarticle'         => '(Nei)',
'yourtext'           => 'Eana Text',

# History pages
'histlast' => 'Neiste',

# Preferences page
'mypreferences' => 'Eistellunga',

# Upload
'watchthisupload' => 'De Seitn beobachtn',

# Miscellaneous special pages
'newpages'     => 'Neie Seitn',
'ancientpages' => 'Scho länger nimma bearbate Artikel',
'move'         => 'vaschiam',

# Special:Log
'all-logs-page' => 'Alle Logbiacha',

# Special:AllPages
'allpages'          => 'Alle Seitn',
'allarticles'       => 'Alle Seitn',
'allinnamespace'    => 'Alle Seitn (Namensraum: $1)',
'allnotinnamespace' => 'Alle Seitn (net im $1 Namensraum)',
'allpagesprev'      => 'Vorige',
'allpagessubmit'    => 'Owendn',
'allpagesprefix'    => 'Seitn zoagn mit Präfix:',

# Watchlist
'mywatchlist'       => 'Beobachtungslistn',
'watchlistanontext' => 'Sie miaßn si $1, um Eanane Beobachtungslistn zum seng oda Einträge auf ihr zum bearbatn.',
'watchnologin'      => 'Sie san net ogmeidt',
'watchthispage'     => 'Seitn beobachtn',
'unwatch'           => 'nimma beobachten',

# Contributions
'contributions' => 'Benutzerbeiträg',
'mycontris'     => 'Eigene Beiträg',

# What links here
'whatlinkshere' => 'Links auf de Seitn',

# Move page
'move-page-legend' => 'Seitn vaschiam',
'move-watch'       => 'De Seitn beobachten',
'1movedto2'        => 'håt [[$1]] nåch [[$2]] verschom',
'1movedto2_redir'  => 'håt [[$1]] nåch [[$2]] verschom und dabei a Weiterleitung überschriem',

# Namespace 8 related
'allmessagesname'     => 'Nam',
'allmessagescurrent'  => 'Aktuella Text',
'allmessagestext'     => 'Des is a Listn vo de MediaWiki-Systemtexte.
Please visit [http://www.mediawiki.org/wiki/Localisation MediaWiki Localisation] and [http://translatewiki.net Betawiki] if you wish to contribute to the generic MediaWiki localisation.',
'allmessagesmodified' => 'Nur geänderte zoagn',

# Special:NewImages
'newimages' => 'Neie Dateien',

);
